@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.1-or-later
 */
@@ -13,9 +13,9 @@
 #include <grantlee/template.h>
 #include <grantlee/templateloader.h>
 #else
-#include <KTextTemplate/engine.h>
-#include <KTextTemplate/template.h>
-#include <KTextTemplate/templateloader.h>
+#include <KTextTemplate/Engine>
+#include <KTextTemplate/Template>
+#include <KTextTemplate/TemplateLoader>
 #endif
 
 namespace GrantleeTheme
