@@ -11,9 +11,9 @@
 #include <grantlee/parser.h>
 #include <grantlee/variable.h>
 #else
-#include <KTextTemplate/exception.h>
-#include <KTextTemplate/parser.h>
-#include <KTextTemplate/variable.h>
+#include <KTextTemplate/Exception>
+#include <KTextTemplate/Parser>
+#include <KTextTemplate/Variable>
 #endif
 
 #include <KIconLoader>
@@ -36,11 +36,9 @@ KTextTemplate::Node *IconTag::getNode(const QString &tagContent, KTextTemplate::
 {
     Q_UNUSED(p)
 
-    static QHash<QString, int> sizeOrGroupLookup = {{QStringLiteral("desktop"), KIconLoader::Desktop},
-                                                    {QStringLiteral("toolbar"), KIconLoader::Toolbar},
+    static QHash<QString, int> sizeOrGroupLookup = {{QStringLiteral("toolbar"), KIconLoader::Toolbar},
                                                     {QStringLiteral("maintoolbar"), KIconLoader::MainToolbar},
                                                     {QStringLiteral("small"), KIconLoader::Small},
-                                                    {QStringLiteral("panel"), KIconLoader::Panel},
                                                     {QStringLiteral("dialog"), KIconLoader::Dialog},
                                                     {QStringLiteral("sizesmall"), KIconLoader::SizeSmall},
                                                     {QStringLiteral("sizesmallmedium"), KIconLoader::SizeSmallMedium},
@@ -130,7 +128,11 @@ void IconNode::render(KTextTemplate::OutputStream *stream, KTextTemplate::Contex
 #else
         const QVariant val = KTextTemplate::Variable(mIconName).resolve(c);
 #endif
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         if (val.type() == QVariant::String) {
+#else
+        if (val.metaType().id() == QMetaType::QString) {
+#endif
             iconName = val.toString();
         } else {
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
